# esxbom.py - Generates BoM out of ekahau predictive project file
#
# Licensed under unlicense - see UNLICENSE file
#
#     <http://unlicense.org/>
#

import argparse
import zipfile
import json

def extractAPs(fname):
    with zipfile.ZipFile(fname) as esx:
        with esx.open('accessPoints.json') as apfile:
            aps = json.load(apfile)
            aplist = {}
            for ap in aps['accessPoints']:
                currentModel = ap['vendor'] + ' ' + ap['model']
                currentModel = normaliseName(str(currentModel))
                if currentModel not in aplist: aplist[currentModel] = 1
                else: aplist[currentModel]+=1
    return aplist

def normaliseName(apname):
    unwanted = {
        " with Dual 5 GHz",
        " 2.4GHz + 5GHz",
        " 5GHz + 5GHz"
    }
    for unwantedstring in unwanted:
        apname = apname.replace(unwantedstring, "")
    return apname

def printAPlist(aplist):
    aplist_sorted = sorted(aplist.items(), key = lambda x:x[1], reverse = True)
    for apname, apcount in aplist_sorted:
        print(f"{apcount}x {apname}")

if __name__ == "__main__":
    parser = argparse.ArgumentParser(prog = 'esxbom.py', description='This script will extract the AP list out of the given ESX file. Note: Antennas will be attached to the APs as in the AP name in the ESX file.')
    parser.add_argument('file', help='ESX file name')
    args = parser.parse_args()

    print("Generating BOM from " +args.file)
    print("-" * 50)

    aplist = extractAPs(args.file)
    printAPlist(aplist)